@@ -1,7 +1,6 @@
-import conf
 from .client import Client
+from .models import *
 
 ALL = [
     'Client',
-    'conf'
 ]
\ No newline at end of file
